@@ -29,7 +29,8 @@ GtkWidget *bitmap_knob_new( GtkAdjustment *,
 							GdkPixbuf *,
 							gint frame_width,
 							gint frame_height,
-							gint frame_count );
+							gint frame_count,
+							gint scaling_factor);
 
 void bitmap_knob_set_bg (GtkWidget *, GdkPixbuf *);
 
