@@ -1,7 +1,7 @@
 /*
  *  Preset.cpp
  *
- *  Copyright (c) 2001-2017 Nick Dowell
+ *  Copyright (c) 2001-2020 Nick Dowell
  *
  *  This file is part of amsynth.
  *
@@ -29,6 +29,7 @@
 #include "VoiceBoard/LowPassFilter.h"
 
 #include <cassert>
+#include <cmath>
 #include <cstdlib>
 #include <cstdio>
 #include <map>
@@ -45,12 +46,11 @@ using namespace std;
 
 static Parameter TimeParameter (const std::string name, Param id)
 {
-	return Parameter (name, id, 0, 0, 2.5f, 0, Parameter::PARAM_POWER, 3, 0.0005f, "s");
+    return Parameter (name, id, 0, 0, 2.5f, 0, Parameter::Law::kPower, 3, 0.0005f, "s");
 }
 
 Preset::Preset			(const std::string name)
 :	mName (name)
-,	nullparam ("null", kAmsynthParameterCount)
 {
 	//										name					id					def min max inc		ControlType			base offset label
 	mParameters.push_back (TimeParameter	("amp_attack",			kAmsynthParameter_AmpEnvAttack));
@@ -64,15 +64,15 @@ Preset::Preset			(const std::string name)
     mParameters.push_back (TimeParameter	("filter_release",		kAmsynthParameter_FilterEnvRelease));
     mParameters.push_back (Parameter		("filter_resonance",	kAmsynthParameter_FilterResonance,	0, 0, 0.97f));
 	mParameters.push_back (Parameter		("filter_env_amount",	kAmsynthParameter_FilterEnvAmount,	0, -16, 16));
-	mParameters.push_back (Parameter		("filter_cutoff",		kAmsynthParameter_FilterCutoff,		1.5, -0.5, 1.5, 0,	Parameter::PARAM_EXP, 16, 0));
-    mParameters.push_back (Parameter		("osc2_detune",			kAmsynthParameter_Oscillator2Detune,		0, -1, 1, 0,		Parameter::PARAM_EXP, 1.25f, 0));
+    mParameters.push_back (Parameter		("filter_cutoff",		kAmsynthParameter_FilterCutoff,		1.5, -0.5, 1.5, 0, Parameter::Law::kExponential, 16, 0));
+    mParameters.push_back (Parameter		("osc2_detune",			kAmsynthParameter_Oscillator2Detune,		0, -1, 1, 0, Parameter::Law::kExponential, 1.25f, 0));
     mParameters.push_back (Parameter		("osc2_waveform",		kAmsynthParameter_Oscillator2Waveform,		2, 0, 4, 1));
-    mParameters.push_back (Parameter		("master_vol",			kAmsynthParameter_MasterVolume,			0.67f, 0, 1, 0,		Parameter::PARAM_POWER, 2, 0));
-    mParameters.push_back (Parameter		("lfo_freq",			kAmsynthParameter_LFOFreq,			0, 0, 7.5, 0,		Parameter::PARAM_POWER, 2, 0,	"Hz"));
+    mParameters.push_back (Parameter		("master_vol",			kAmsynthParameter_MasterVolume,			0.67f, 0, 1, 0, Parameter::Law::kPower, 2, 0));
+    mParameters.push_back (Parameter		("lfo_freq",			kAmsynthParameter_LFOFreq,			0, 0, 7.5, 0, Parameter::Law::kPower, 2, 0,	"Hz"));
     mParameters.push_back (Parameter		("lfo_waveform",		kAmsynthParameter_LFOWaveform,		0, 0, 6, 1));
-    mParameters.push_back (Parameter		("osc2_range",			kAmsynthParameter_Oscillator2Octave,		0, -3, 4, 1,		Parameter::PARAM_EXP, 2, 0));
+    mParameters.push_back (Parameter		("osc2_range",			kAmsynthParameter_Oscillator2Octave,		0, -3, 4, 1, Parameter::Law::kExponential, 2, 0));
 	mParameters.push_back (Parameter		("osc_mix",				kAmsynthParameter_OscillatorMix,			0, -1, 1));
-	mParameters.push_back (Parameter		("freq_mod_amount",		kAmsynthParameter_LFOToOscillators,		0, 0, 1.25992105f,0,Parameter::PARAM_POWER, 3, -1));
+    mParameters.push_back (Parameter		("freq_mod_amount",		kAmsynthParameter_LFOToOscillators,		0, 0, 1.25992105f, 0, Parameter::Law::kPower, 3, -1));
 	mParameters.push_back (Parameter		("filter_mod_amount",	kAmsynthParameter_LFOToFilterCutoff,	-1, -1, 1));
 	mParameters.push_back (Parameter		("amp_mod_amount",		kAmsynthParameter_LFOToAmp,		-1, -1, 1));
 	mParameters.push_back (Parameter		("osc_mix_mode",		kAmsynthParameter_OscillatorMixRingMod,		0, 0, 1, 0));
@@ -87,8 +87,8 @@ Preset::Preset			(const std::string name)
 	mParameters.push_back (Parameter		("portamento_time",		kAmsynthParameter_PortamentoTime, 0.0f, 0.0f, 1.0f));
 	mParameters.push_back (Parameter		("keyboard_mode",		kAmsynthParameter_KeyboardMode, KeyboardModePoly, 0, KeyboardModeLegato, 1));
 	mParameters.push_back (Parameter		("osc2_pitch",			kAmsynthParameter_Oscillator2Pitch, 0, -12, +12, 1));
-	mParameters.push_back (Parameter		("filter_type",         kAmsynthParameter_FilterType, SynthFilter::FilterTypeLowPass, SynthFilter::FilterTypeLowPass, SynthFilter::FilterTypeCount - 1, 1));
-	mParameters.push_back (Parameter		("filter_slope",        kAmsynthParameter_FilterSlope, SynthFilter::FilterSlope24, SynthFilter::FilterSlope12, SynthFilter::FilterSlope24, 1));
+	mParameters.push_back (Parameter		("filter_type",         kAmsynthParameter_FilterType, (int)SynthFilter::Type::kLowPass, (int)SynthFilter::Type::kLowPass, (int)SynthFilter::Type::kBypass, 1));
+	mParameters.push_back (Parameter		("filter_slope",        kAmsynthParameter_FilterSlope, (int)SynthFilter::Slope::k24, (int)SynthFilter::Slope::k12, (int)SynthFilter::Slope::k24, 1));
 	mParameters.push_back (Parameter		("freq_mod_osc",		kAmsynthParameter_LFOOscillatorSelect, 0, 0, 2, 1));
 	mParameters.push_back (Parameter		("filter_kbd_track",    kAmsynthParameter_FilterKeyTrackAmount, 1));
 	mParameters.push_back (Parameter		("filter_vel_sens",		kAmsynthParameter_FilterKeyVelocityAmount, 1));
@@ -140,15 +140,19 @@ Preset::getParameter(const std::string name)
 void
 Preset::randomise()
 {
-	float master_vol = getParameter("master_vol").getValue ();
-	for (unsigned i=0; i<mParameters.size(); i++) getParameter(i).random_val();
-	getParameter("master_vol").setValue (master_vol);
+	for (auto &parameter : mParameters) {
+		if (parameter.getId() != kAmsynthParameter_MasterVolume) {
+			parameter.randomise();
+		}
+	}
 }
 
 void
 Preset::AddListenerToAll	(UpdateListener* ul)
 {
-	for (unsigned i=0; i<mParameters.size(); i++) getParameter(i).addUpdateListener (*ul);
+	for (auto &parameter : mParameters) {
+		parameter.addUpdateListener(ul);
+	}
 }
 
 void
@@ -233,7 +237,7 @@ const char *parameter_name_from_index (int param_index)
 {
 	const Preset &_preset = _get_preset();
 	if (param_index < 0 || param_index >= (int)_preset.ParameterCount())
-		return NULL;
+		return nullptr;
 	static std::vector<std::string> names;
 	if (names.empty())
 		names.resize(_preset.ParameterCount());
@@ -302,7 +306,7 @@ int parameter_get_display (int parameter_index, float parameter_value, char *buf
 		case kAmsynthParameter_FilterKeyTrackAmount:
 		case kAmsynthParameter_FilterKeyVelocityAmount:
 		case kAmsynthParameter_AmpVelocityAmount:
-			return snprintf(buffer, maxlen, "%d %%", (int)roundf(parameter.GetNormalisedValue() * 100.f));
+			return snprintf(buffer, maxlen, "%d %%", (int)roundf(parameter.getNormalisedValue() * 100.f));
 		case kAmsynthParameter_FilterType: {
             const char **filter_type_names = parameter_get_value_strings(parameter_index);
             if (filter_type_names) {
@@ -320,7 +324,7 @@ const char **parameter_get_value_strings (int parameter_index)
 {
     static std::vector<std::vector<const char *> > parameterStrings(kAmsynthParameterCount);
     if (parameter_index < 0 || parameter_index >= (int)parameterStrings.size())
-        return NULL;
+        return nullptr;
 
     std::vector<const char *> & strings = parameterStrings[parameter_index];
     if (strings.empty()) {
