@@ -1,7 +1,7 @@
 /*
  *  types.h
  *
- *  Copyright (c) 2014 Nick Dowell
+ *  Copyright (c) 2014-2016 Nick Dowell
  *
  *  This file is part of amsynth.
  *
@@ -22,7 +22,11 @@
 #ifndef __amsynth__types__
 #define __amsynth__types__
 
+#if _WIN32
+#define DEPRECATED
+#else
 #define DEPRECATED __attribute__((deprecated))
+#endif
 
 struct amsynth_midi_event_t {
 	unsigned int offset_frames;
@@ -30,4 +34,10 @@ struct amsynth_midi_event_t {
 	unsigned char *buffer;
 };
 
+struct amsynth_midi_cc_t {
+	unsigned char channel;
+	unsigned char cc;
+	unsigned char value;
+};
+
 #endif
